@@ -1,14 +1,10 @@
 __all__ = [
     'api_helper',
     'configuration',
-    'configuration_v2',
     'models',
-    'models_v2',
     'controllers',
-    'controllers_v2',
     'http',
     'exceptions',
     'decorators',
     'cohesity_client',
-    'cohesity_client_v2',
-]
+]
\ No newline at end of file
