@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2021 Cohesity Inc.
 
 import logging
 from cohesity_management_sdk.api_helper import APIHelper
@@ -28,7 +28,6 @@ class ProtectionSourcesController(BaseController):
 
     def get_download_physical_agent(self,
                                     host_type,
-                                    host_os_type=None,
                                     pkg_type=None,
                                     agent_type=None):
         """Does a GET request to /public/physicalAgents/download.
@@ -44,15 +43,6 @@ class ProtectionSourcesController(BaseController):
                 the Oracle Solaris operating system. 'kSapHana' indicates the
                 Sap Hana database system developed by SAP SE. 'kOther'
                 indicates the other types of operating system.
-            host_os_type (HostOSTypeEnum, optional): Specifies the OS type for
-                which user wants to download the
-                physical agent/plugin.
-                'kLinux' indicates the Linux operating system.
-                'kWindows' indicates the Microsoft Windows operating system.
-                'kAix' indicates the IBM AIX operating system.
-                'kSolaris' indicates the Oracle Solaris operating system.
-                'kSapHana' indicates the Sap Hana database system developed by SAP SE.
-                'kOther' indicates the other types of operating system.
             pkg_type (PkgTypeEnum, optional): Specifies the Linux installer
                 package type applicable only to Linux OS and the value can be
                 any of ("kScript","kRPM", "kSuseRPM", "kDEB") 'kScript'
@@ -91,7 +81,6 @@ class ProtectionSourcesController(BaseController):
             _query_builder += _url_path
             _query_parameters = {
                 'hostType': host_type,
-                'hostOSType': host_os_type,
                 'pkgType': pkg_type,
                 'agentType': agent_type
             }
@@ -224,8 +213,6 @@ class ProtectionSourcesController(BaseController):
                                 num_levels=None,
                                 exclude_types=None,
                                 exclude_aws_types=None,
-                                exclude_kubernetes_types=None,
-                                exclude_office_365_types=None,
                                 include_datastores=None,
                                 include_networks=None,
                                 include_vm_folders=None,
@@ -236,9 +223,6 @@ class ProtectionSourcesController(BaseController):
                                 sids=None,
                                 include_source_credentials=None,
                                 encryption_key=None,
-                                include_object_protection_info=None,
-                                prune_non_critical_info=None,
-                                prune_aggregation_info=None,
                                 tenant_ids=None,
                                 all_under_hierarchy=None):
         """Does a GET request to /public/protectionSources.
@@ -284,20 +268,9 @@ class ProtectionSourcesController(BaseController):
                 from being returned.
             exclude_aws_types (list of ExcludeAwsTypeEnum, optional): Specifies
                 the Object types to be filtered out for AWS that match the
-                passed in types such as 'kEC2Instance', 'kRDSInstance' & 'kAuroraCluster'.
-                For example, set this parameter to 'kEC2Instance' to exclude ec2 instance
-                from being returned.
-            exclude_kubernetes_types (list of ExcludeKubernetesTypesEnum, optional):
-                Specifies the Object types to be filtered out for Kubernetes that match
-                the passed in types such as 'kService'.
-                For example, set this parameter to 'kService' to exclude services
-                from being returned.
-            exclude_office_365_types (list of ExcludeOffice365TypesEnum):
-                Specifies the Object types to be filtered out for Office 365
-                that match the passed in types such as 'kDomain', 'kOutlook',
-                'kMailbox', etc.
-                For example, set this parameter to 'kMailbox' to exclude Mailbox
-                Objects from being returned.
+                passed in types such as 'kEC2Instance', 'kRDSInstance' etc.
+                For example, set this parameter to 'kEC2Instance' to exclude
+                ec2 instance from being returned.
             include_datastores (bool, optional): Set this parameter to true to
                 also return kDatastore object types found in the Source in
                 addition to their Object subtrees. By default, datastores are
@@ -337,16 +310,6 @@ class ProtectionSourcesController(BaseController):
             encryption_key (string, optional): Key to be used to encrypt the
                 source credential. If include_source_credentials is set to true
                 this key must be specified.
-            include_object_protection_info (bool, optional): If specified, the
-                object protection of entities(if any) will be returned.
-            prune_non_critical_info (bool, optional): Specifies whether to
-                prune non critical info within entities.
-                Incase of VMs, virtual disk information will be pruned.
-                Incase of Office365, metadata about user entities will be pruned.
-                This can be used to limit the size of the response by caller.
-            prune_aggregation_info (bool): Specifies whether to prune the
-                aggregation information about the number of entities
-                protected/unprotected.
             tenant_ids (list of string, optional): TenantIds contains ids of
                 the tenants for which objects are to be returned.
             all_under_hierarchy (bool, optional): AllUnderHierarchy specifies
@@ -383,8 +346,6 @@ class ProtectionSourcesController(BaseController):
                 'numLevels': num_levels,
                 'excludeTypes': exclude_types,
                 'excludeAwsTypes': exclude_aws_types,
-                'excludeOffice365Types': exclude_office_365_types,
-                'ExcludeKubernetesTypes': exclude_kubernetes_types,
                 'includeDatastores': include_datastores,
                 'includeNetworks': include_networks,
                 'includeVMFolders': include_vm_folders,
@@ -395,9 +356,6 @@ class ProtectionSourcesController(BaseController):
                 'sids': sids,
                 'includeSourceCredentials': include_source_credentials,
                 'encryptionKey': encryption_key,
-                'IncludeObjectProtectionInfo': include_object_protection_info,
-                'pruneNonCriticalInfo':prune_non_critical_info,
-                'pruneAggregationInfo':prune_aggregation_info,
                 'tenantIds': tenant_ids,
                 'allUnderHierarchy': all_under_hierarchy
             }
@@ -499,7 +457,7 @@ class ProtectionSourcesController(BaseController):
                 indicates Hdfs Protection Source environment. 'kHive'
                 indicates Hive Protection Source environment. 'kHBase'
                 indicates HBase Protection Source environment.
-                'kUDA' indicates Universal Data Adapter Protection Source environment.
+
             protection_source_id (long|int, optional): Specifies the
                 Protection Source Id of the 'kPhysical' or 'kVMware' entity in
                 the Protection Source tree hosting the applications.
@@ -551,8 +509,8 @@ class ProtectionSourcesController(BaseController):
                 environment. 'kHdfs' indicates Hdfs Protection Source
                 environment. 'kHive' indicates Hive Protection Source
                 environment. 'kHBase' indicates HBase Protection Source
-                environment. 'kUDA' indicates Universal Data Adapter Protection
-                Source environment.
+                environment.
+
 
         Returns:
             list of RegisteredApplicationServer: Response from the API.
@@ -1234,8 +1192,7 @@ class ProtectionSourcesController(BaseController):
                                environment,
                                id,
                                all_under_hierarchy=None,
-                               include_rpo_snapshots=None,
-                               prune_protection_job_metadata=None):
+                               include_rpo_snapshots=None):
         """Does a GET request to /public/protectionSources/protectedObjects.
 
         Returns the list of protected Objects in a registered Protection
@@ -1294,8 +1251,7 @@ class ProtectionSourcesController(BaseController):
                 Source environment. 'kHdfs' indicates Hdfs Protection Source
                 environment. 'kHive' indicates Hive Protection Source
                 environment. 'kHBase' indicates HBase Protection Source
-                environment. 'kUDA' indicates Universal Data Adapter Protection
-                Source environment.
+                environment.
             id (long|int): Specifies the Id of a registered Protection Source
                 of the type given in environment.
             all_under_hierarchy (bool, optional): AllUnderHierarchy specifies
@@ -1304,11 +1260,6 @@ class ProtectionSourcesController(BaseController):
             include_rpo_snapshots (bool, optional): If true, then the
                 Protected Objects protected by RPO policies will also be
                 returned.
-            prune_protection_job_metadata (bool, optional): Specifies whether
-                the metadata about the protection job is to be pruned.
-                If set to true, only ID, name & policy info will be returned.
-                Info about indexing, entities within the job and other additional settings
-                will be omitted.
 
         Returns:
             list of ProtectedVmInfo: Response from the API. Success
@@ -1337,8 +1288,7 @@ class ProtectionSourcesController(BaseController):
                 'environment': environment,
                 'id': id,
                 'allUnderHierarchy': all_under_hierarchy,
-                'includeRpoSnapshots': include_rpo_snapshots,
-                'pruneProtectionJobMetadata': prune_protection_job_metadata
+                'includeRpoSnapshots': include_rpo_snapshots
             }
             _query_builder = APIHelper.append_url_with_query_parameters(
                 _query_builder, _query_parameters,
@@ -1530,7 +1480,6 @@ class ProtectionSourcesController(BaseController):
         include_source_credentials=None,
         encryption_key=None,
         include_applications_tree_info=None,
-        prune_non_critical_info=None,
         tenant_ids=None,
         all_under_hierarchy=None):
         """Does a GET request to /public/protectionSources/registrationInfo.
@@ -1565,11 +1514,6 @@ class ProtectionSourcesController(BaseController):
                 this key must be specified.
             include_applications_tree_info (bool, optional): Specifies whether
                 to return applications tree info or not.
-            prune_non_critical_info (bool, optional): Specifies whether to prune
-                non critical info within entities.
-                Incase of VMs, virtual disk information will be pruned.
-                Incase of Office365, metadata about user entities will be pruned.
-                This can be used to limit the size of the response by caller.
             tenant_ids (list of string, optional): TenantIds contains ids of
                 the tenants for which objects are to be returned.
             all_under_hierarchy (bool, optional): AllUnderHierarchy specifies
@@ -1605,7 +1549,6 @@ class ProtectionSourcesController(BaseController):
                 'includeSourceCredentials': include_source_credentials,
                 'encryptionKey': encryption_key,
                 'includeApplicationsTreeInfo':include_applications_tree_info,
-                'pruneNonCriticalInfo': prune_non_critical_info,
                 'tenantIds': tenant_ids,
                 'allUnderHierarchy': all_under_hierarchy
             }
