@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2021 Cohesity Inc.
 
 
 class AcropolisProtectionSource(object):
@@ -28,11 +28,13 @@ class AcropolisProtectionSource(object):
             kVirtualMachine.
         ngt_version (string): Specifies version of NGT installed on the VM.
             This is applicable to acropolis entity of type kVirtualMachine.
-        mtype (int): Specifies the type of an Acropolis Protection Source Object
-            such as 'kPrismCentral', 'kHost', 'kNetwork', etc.
+        mtype (int): Specifies the type of an Acropolis Protection Source
+            Object such as 'kPrismCentral', 'kHost', 'kNetwork', etc.
         uuid (string): Specifies the UUID of the Acropolis Object. This is
             unique within the cluster instance. Together with clusterUuid,
             this entity is unique within the Acropolis environment.
+        version (string, optional): Specifies the version of an Acropolis
+            cluster or standalone cluster.
 
     """
 
@@ -48,7 +50,8 @@ class AcropolisProtectionSource(object):
         "ngt_reachable":'ngtReachable',
         "ngt_version":'ngtVersion',
         "mtype":'type',
-        "uuid":'uuid'
+        "uuid":'uuid',
+        "version":'version'
     }
 
     def __init__(self,
@@ -62,7 +65,8 @@ class AcropolisProtectionSource(object):
                  ngt_reachable=None,
                  ngt_version=None,
                  mtype=None,
-                 uuid=None):
+                 uuid=None,
+                 version=None):
         """Constructor for the AcropolisProtectionSource class"""
 
         # Initialize members of the class
@@ -77,6 +81,7 @@ class AcropolisProtectionSource(object):
         self.ngt_version = ngt_version
         self.mtype = mtype
         self.uuid = uuid
+        self.version = version
 
 
     @classmethod
@@ -108,6 +113,7 @@ class AcropolisProtectionSource(object):
         ngt_version = dictionary.get('ngtVersion')
         mtype = dictionary.get('type')
         uuid = dictionary.get('uuid')
+        version = dictionary.get('version')
 
         # Return an object of this model
         return cls(cluster_uuid,
@@ -120,6 +126,7 @@ class AcropolisProtectionSource(object):
                    ngt_reachable,
                    ngt_version,
                    mtype,
-                   uuid)
+                   uuid,
+                   version)
 
 
