@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2021 Cohesity Inc.
 
 import cohesity_management_sdk.models.alert_document
 import cohesity_management_sdk.models.alert_property
@@ -49,7 +49,7 @@ class Alert(object):
             kArchivalRestore - Alert associated with Archival-Restore job.
             kRemoteReplication - Alert associated with Replication job.
             kQuota - Alert associated with Quotas.
-            kCDP - Alert associated with Continuous Data Protection.
+
         alert_code (string): Specifies a unique code that categorizes the
             Alert, for example: CE00200014, where CE stands for Cohesity
             Error, the alert state next 3 digits is the id of the Alert
@@ -101,8 +101,6 @@ class Alert(object):
         resolution_details (AlertResolutionDetails): Specifies information
             about the Alert Resolution such as a summary, id assigned by the
             Cohesity Cluster, user who resolved the Alerts, etc.
-        resolved_timestamp_usecs (long|int): Specifies Unix epoch Timestamps
-            in microseconds when alert is resolved.
         severity (SeverityEnum): Specifies the severity level of an Alert.
             kCritical - Alerts whose severity type is Critical. kWarning -
             Alerts whose severity type is Warning. kInfo - Alerts whose
@@ -132,7 +130,6 @@ class Alert(object):
         "latest_timestamp_usecs":'latestTimestampUsecs',
         "property_list":'propertyList',
         "resolution_details":'resolutionDetails',
-        "resolved_timestamp_usecs":'resolvedTimestampUsecs',
         "severity":'severity',
         "suppression_id":'suppressionId',
         "tenant_ids":'tenantIds'
@@ -155,7 +152,6 @@ class Alert(object):
                  latest_timestamp_usecs=None,
                  property_list=None,
                  resolution_details=None,
-                 resolved_timestamp_usecs=None,
                  severity=None,
                  suppression_id=None,
                  tenant_ids=None):
@@ -178,7 +174,6 @@ class Alert(object):
         self.latest_timestamp_usecs = latest_timestamp_usecs
         self.property_list = property_list
         self.resolution_details = resolution_details
-        self.resolved_timestamp_usecs = resolved_timestamp_usecs
         self.severity = severity
         self.suppression_id = suppression_id
         self.tenant_ids = tenant_ids
@@ -222,7 +217,6 @@ class Alert(object):
             for structure in dictionary.get('propertyList'):
                 property_list.append(cohesity_management_sdk.models.alert_property.AlertProperty.from_dictionary(structure))
         resolution_details = cohesity_management_sdk.models.alert_resolution_details.AlertResolutionDetails.from_dictionary(dictionary.get('resolutionDetails')) if dictionary.get('resolutionDetails') else None
-        resolved_timestamp_usecs = dictionary.get('resolvedTimestampUsecs')
         severity = dictionary.get('severity')
         suppression_id = dictionary.get('suppressionId')
         tenant_ids = dictionary.get('tenantIds')
@@ -244,7 +238,6 @@ class Alert(object):
                    latest_timestamp_usecs,
                    property_list,
                    resolution_details,
-                   resolved_timestamp_usecs,
                    severity,
                    suppression_id,
                    tenant_ids)
