@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2021 Cohesity Inc.
 
 import cohesity_management_sdk.models.c_2_s_access_portal
 
@@ -31,10 +31,6 @@ class AmazonCloudCredentials(object):
         c_2_s_access_portal (C2SAccessPortal): Specifies information required
             to connect to CAP to get AWS credentials. C2SAccessPortal(CAP) is
             AWS commercial cloud service access portal.
-        credential_blob (string): Specifies the credential blob to authenticate
-            with credential endpoint.
-        credential_endpoint (string): Specifies the credential process that
-            generates the security token.
         iam_role_arn (string): Specifies the iam role arn Amazon service
             account. See the Cohesity online help for the value to specify for
             this field based on the current S3-compatible Vault (External
@@ -91,8 +87,6 @@ class AmazonCloudCredentials(object):
         "access_key_id":'accessKeyId',
         "auth_method":'authMethod',
         "c_2_s_access_portal":'c2sAccessPortal',
-        "credential_blob":'credentialBlob',
-        "credential_endpoint":'credentialEndpoint',
         "iam_role_arn":'iamRoleArn',
         "read_only_iam_role_arn":'readOnlyIamRoleArn',
         "region":'region',
@@ -109,8 +103,6 @@ class AmazonCloudCredentials(object):
                  access_key_id=None,
                  auth_method=None,
                  c_2_s_access_portal=None,
-                 credential_blob=None,
-                 credential_endpoint=None,
                  iam_role_arn=None,
                  read_only_iam_role_arn=None,
                  region=None,
@@ -127,8 +119,6 @@ class AmazonCloudCredentials(object):
         self.access_key_id = access_key_id
         self.auth_method = auth_method
         self.c_2_s_access_portal = c_2_s_access_portal
-        self.credential_blob = credential_blob
-        self.credential_endpoint = credential_endpoint
         self.iam_role_arn = iam_role_arn
         self.read_only_iam_role_arn = read_only_iam_role_arn
         self.region = region
@@ -162,8 +152,6 @@ class AmazonCloudCredentials(object):
         access_key_id = dictionary.get('accessKeyId')
         auth_method = dictionary.get('authMethod')
         c_2_s_access_portal = cohesity_management_sdk.models.c_2_s_access_portal.C2SAccessPortal.from_dictionary(dictionary.get('c2sAccessPortal')) if dictionary.get('c2sAccessPortal') else None
-        credential_blob = dictionary.get('credentialBlob')
-        credential_endpoint = dictionary.get('credentialEndpoint')
         iam_role_arn = dictionary.get('iamRoleArn')
         read_only_iam_role_arn = dictionary.get('readOnlyIamRoleArn')
         region = dictionary.get('region')
@@ -179,8 +167,6 @@ class AmazonCloudCredentials(object):
                    access_key_id,
                    auth_method,
                    c_2_s_access_portal,
-                   credential_blob,
-                   credential_endpoint,
                    iam_role_arn,
                    read_only_iam_role_arn,
                    region,
