@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2021 Cohesity Inc.
 
 class AzureTypeEnum(object):
 
@@ -25,7 +25,6 @@ class AzureTypeEnum(object):
     'kSubnet' represents a subnet within the virtual network.
     'kComputeOptions' indicates the number of CPU cores and memory size
     available for a type of a Virtual Machine.
-    'kAvailabilitySet' indicates the availability set.
 
     Attributes:
         KSUBSCRIPTION: TODO: type description here.
@@ -41,7 +40,7 @@ class AzureTypeEnum(object):
         KNETWORKRESOURCEGROUP: TODO: type description here.
         KSUBNET: TODO: type description here.
         KCOMPUTEOPTIONS: TODO: type description here.
-        KAVAILABILITYSET: TODO: type description here.
+
     """
 
     KSUBSCRIPTION = 'kSubscription'
@@ -70,5 +69,3 @@ class AzureTypeEnum(object):
 
     KCOMPUTEOPTIONS = 'kComputeOptions'
 
-    KAVAILABILITYSET = 'kAvailabilitySet'
-
