@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2021 Cohesity Inc.
 
 class CategoryNotificationRuleEnum(object):
 
@@ -38,7 +38,6 @@ class CategoryNotificationRuleEnum(object):
     kArchivalRestore - Alert associated with Archival-Restore job.
     kRemoteReplication - Alert associated with Replication job.
     kQuota - Alert associated with Quotas.
-    kCDP - Alert associated with Continuous Data Protection.
 
     Attributes:
         KDISK: TODO: type description here.
@@ -72,7 +71,7 @@ class CategoryNotificationRuleEnum(object):
         KARCHIVALRESTORE: TODO: type description here.
         KREMOTEREPLICATION: TODO: type description here.
         KQUOTA: TODO: type description here.
-        KCDP: TODO: type description here.
+
 
     """
 
@@ -138,4 +137,3 @@ class CategoryNotificationRuleEnum(object):
 
     KQUOTA = 'kQuota'
 
-    KCDP = 'kCDP'
\ No newline at end of file
