@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2021 Cohesity Inc.
 
 class EnvironmentGetProtectionJobsEnum(object):
 
@@ -38,7 +38,7 @@ class EnvironmentGetProtectionJobsEnum(object):
         KGCPNATIVE: TODO: type description here.
         KKUBERNETES: TODO: type description here.
         KELASTIFILE: TODO: type description here.
-
+        KUDA: TODO: type description here.
 
     """
 
@@ -101,3 +101,5 @@ class EnvironmentGetProtectionJobsEnum(object):
     KKUBERNETES = 'kKubernetes'
 
     KELASTIFILE = 'kElastifile'
+
+    KUDA = 'kUDA'
\ No newline at end of file
