@@ -1,9 +1,8 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2021 Cohesity Inc.
 
 import cohesity_management_sdk.models.aws_snapshot_manager_parameters
 import cohesity_management_sdk.models.exchange_env_job_parameters
-import cohesity_management_sdk.models.externally_triggered_env_job_parameters
 import cohesity_management_sdk.models.hyperv_env_job_parameters
 import cohesity_management_sdk.models.nas_env_job_parameters
 import cohesity_management_sdk.models.office_365_env_job_parameters
@@ -29,9 +28,6 @@ class EnvironmentTypeJobParameters(object):
         exchange_parameters (ExchangeEnvJobParameters): Specifies additional
             special parameters that are applicable only to Types of
             'kExchange' type.
-        externally_triggered_job_parameters (ExternallyTriggeredEnvJobParameters):
-            Specifies additional special parameters that are applicable only to
-            externally triggered backup jobs of 'kView' type.
         hyperv_parameters (HypervEnvJobParameters): Specifies job parameters
             applicable for all 'kHyperV' Environment type Protection Sources
             in a Protection Job.
@@ -65,7 +61,6 @@ class EnvironmentTypeJobParameters(object):
     _names = {
         "aws_snapshot_parameters":'awsSnapshotParameters',
         "exchange_parameters":'exchangeParameters',
-        "externally_triggered_job_parameters":'externallyTriggeredJobParameters',
         "hyperv_parameters":'hypervParameters',
         "nas_parameters":'nasParameters',
         "office_365_parameters":'office365Parameters',
@@ -79,7 +74,6 @@ class EnvironmentTypeJobParameters(object):
     def __init__(self,
                  aws_snapshot_parameters=None,
                  exchange_parameters=None,
-                 externally_triggered_job_parameters=None,
                  hyperv_parameters=None,
                  nas_parameters=None,
                  office_365_parameters=None,
@@ -93,7 +87,6 @@ class EnvironmentTypeJobParameters(object):
         # Initialize members of the class
         self.aws_snapshot_parameters = aws_snapshot_parameters
         self.exchange_parameters = exchange_parameters
-        self.externally_triggered_job_parameters = externally_triggered_job_parameters
         self.hyperv_parameters = hyperv_parameters
         self.nas_parameters = nas_parameters
         self.office_365_parameters = office_365_parameters
@@ -124,7 +117,6 @@ class EnvironmentTypeJobParameters(object):
         # Extract variables from the dictionary
         aws_snapshot_parameters = cohesity_management_sdk.models.aws_snapshot_manager_parameters.AwsSnapshotManagerParameters.from_dictionary(dictionary.get('awsSnapshotParameters')) if dictionary.get('awsSnapshotParameters') else None
         exchange_parameters = cohesity_management_sdk.models.exchange_env_job_parameters.ExchangeEnvJobParameters.from_dictionary(dictionary.get('exchangeParameters')) if dictionary.get('exchangeParameters') else None
-        externally_triggered_job_parameters = cohesity_management_sdk.models.externally_triggered_env_job_parameters.ExternallyTriggeredEnvJobParameters.from_dictionary(dictionary.get('externallyTriggeredJobParameters')) if dictionary.get('externallyTriggeredJobParameters') else None
         hyperv_parameters = cohesity_management_sdk.models.hyperv_env_job_parameters.HypervEnvJobParameters.from_dictionary(dictionary.get('hypervParameters')) if dictionary.get('hypervParameters') else None
         nas_parameters = cohesity_management_sdk.models.nas_env_job_parameters.NasEnvJobParameters.from_dictionary(dictionary.get('nasParameters')) if dictionary.get('nasParameters') else None
         office_365_parameters = cohesity_management_sdk.models.office_365_env_job_parameters.Office365EnvJobParameters.from_dictionary(dictionary.get('office365Parameters')) if dictionary.get('office365Parameters') else None
@@ -137,7 +129,6 @@ class EnvironmentTypeJobParameters(object):
         # Return an object of this model
         return cls(aws_snapshot_parameters,
                    exchange_parameters,
-                   externally_triggered_job_parameters,
                    hyperv_parameters,
                    nas_parameters,
                    office_365_parameters,
