@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2021 Cohesity Inc.
 
 class ObjectClassActiveDirectoryPrincipalsAddParametersEnum(object):
 
@@ -12,14 +12,12 @@ class ObjectClassActiveDirectoryPrincipalsAddParametersEnum(object):
     'kGroup' specifies a group object class.
     'kComputer' specifies a computer object class.
     'kWellKnownPrincipal' specifies a well known principal.
-    'kServiceAccount' specifies a service account object class.
 
     Attributes:
         KUSER: TODO: type description here.
         KGROUP: TODO: type description here.
         KCOMPUTER: TODO: type description here.
         KWELLKNOWNPRINCIPAL: TODO: type description here.
-        KSERVICEACCOUNT: TODO: type description here.
 
     """
 
@@ -31,4 +29,3 @@ class ObjectClassActiveDirectoryPrincipalsAddParametersEnum(object):
 
     KWELLKNOWNPRINCIPAL = 'kWellKnownPrincipal'
 
-    KSERVICEACCOUNT = 'kServiceAccount'
\ No newline at end of file
