@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2021 Cohesity Inc.
 
 class ObjectClassSearchActiveDirectoryPrincipalsEnum(object):
 
@@ -12,7 +12,6 @@ class ObjectClassSearchActiveDirectoryPrincipalsEnum(object):
         KGROUP: TODO: type description here.
         KCOMPUTER: TODO: type description here.
         KWELLKNOWNPRINCIPAL: TODO: type description here.
-        KSERVICEACCOUNT: TODO: type description here.
 
     """
 
@@ -24,4 +23,3 @@ class ObjectClassSearchActiveDirectoryPrincipalsEnum(object):
 
     KWELLKNOWNPRINCIPAL = 'kWellKnownPrincipal'
 
-    KSERVICEACCOUNT = 'kServiceAccount'
