@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2021 Cohesity Inc.
 
 import cohesity_management_sdk.models.alerting_config
 import cohesity_management_sdk.models.cloud_parameters
@@ -12,7 +12,6 @@ import cohesity_management_sdk.models.backup_script
 import cohesity_management_sdk.models.remote_job_script
 import cohesity_management_sdk.models.remote_view_config
 import cohesity_management_sdk.models.source_special_parameter
-import cohesity_management_sdk.models.protection_source
 import cohesity_management_sdk.models.protection_job_summary_stats
 import cohesity_management_sdk.models.universal_id
 
@@ -23,6 +22,9 @@ class ProtectionJob(object):
     Provides details about a Protection Job.
 
     Attributes:
+        leverage_san_transport (bool):  If this field is set to true, then the
+            backup for the objects will be performed using dedicated storage
+            area network (SAN) instead of LAN or managment network.
         abort_in_blackout_period (bool): If true, the Cohesity Cluster aborts
             any currently executing Job Runs of this Protection Job when a
             blackout period specified for this Job starts, even if the Job Run
@@ -38,9 +40,6 @@ class ProtectionJob(object):
             succeeded. 'kFailure' means the Protection Job failed.
             'kSlaViolation' means the Protection Job took longer than the time
             period specified in the SLA.
-        allow_parallel_runs (bool): If this field is set to true, then we will
-            allow parallel runs for the job for the adapters which support
-            parallel runs.
         cloud_parameters (CloudParameters): Specifies Cloud parameters that
             are applicable to all Protection Sources in a Protection Job in
             certain scenarios.
@@ -48,10 +47,6 @@ class ProtectionJob(object):
             quiesce failure.
         create_remote_view (bool): Specifies whether to create a remote view
             name to use for view overwrite.
-            This field is deprecated. Remote view names will automatically be
-            used for all view jobs with replication policy. Use
-            RemoteViewConfigList to setup remote view names.
-            deprecated: true
         creation_time_usecs (long|int): Specifies the time when the Protection
             Job was created.
         data_migration_policy (DataMigrationPolicy): Specifies settings for
@@ -108,19 +103,10 @@ class ProtectionJob(object):
             environment. 'kCouchbase' indicates Couchbase Protection Source
             environment. 'kHdfs' indicates Hdfs Protection Source environment.
             'kHive' indicates Hive Protection Source environment. 'kHBase'
-            indicates HBase Protection Source environment. 'kUDA' indicates
-            Universal Data Adapter Protection Source environment.
+            indicates HBase Protection Source environment.
         environment_parameters (EnvironmentTypeJobParameters): Specifies
             additional parameters that are common to all Protection Sources in
             a Protection Job created for a particular environment type.
-        exclude_label_ids (list of long|int): Array of arrays of label IDs that
-            specify labels to exclude.
-            Optionally specify a list of labels to exclude from protecting by
-            listing protection source ids of labels in this two dimensional
-            array. Using this two dimensional array of label IDs, the
-            Cluster generates a list of namespaces to exclude from protecting,
-            which are derived from intersections of the inner arrays
-            and union of the outer array.
         exclude_source_ids (list of long|int): Array of Excluded Source
             Objects.  List of Object ids from a Protection Source that should
             not be protected and are excluded from being backed up by the
@@ -190,13 +176,6 @@ class ProtectionJob(object):
         is_paused (bool): Indicates if the Protection Job is paused, which
             means that no new Job Runs are started but any existing Job Runs
             continue to execute.
-        label_ids (list of long|int): Array of array of label IDs that specify
-            labels to protect.
-            Optionally specify a list of labels to protect by listing
-            protection source ids of labels in this two dimensional array.
-            Using this two dimensional array of label IDs, the cluster
-            generates a list of namespaces to protect, which are derived from
-            intersections of the inner arrays and union of the outer array.
         last_run (ProtectionRunInstance): Specifies the status of one Job Run.
             A Job Run can have one Backup Run and zero or more Copy Runs.
         leverage_nutanix_snapshots (bool): Specifies whether to leverage
@@ -205,9 +184,6 @@ class ProtectionJob(object):
             registered as a management server has to be registered as a
             source. If nutanix snapshot can not be taken, job will fall back
             to default mode.
-        leverage_san_transport (bool): If this field is set to true, then the
-            backup for the objects will be performed using dedicated storage
-            area network (SAN) instead of LAN or managment network.
         leverage_storage_snapshots (bool): Specifies whether to leverage the
             storage array based snapshots for this backup job. To leverage
             storage snapshots, the storage array has to be registered as a
@@ -215,8 +191,6 @@ class ProtectionJob(object):
             fallback to the default backup method.
         leverage_storage_snapshots_for_hyperflex (bool): Specifies whether to
             leverage Hyperflex as the storage snapshot array
-        missing_entities (list of ProtectionSource): Specifies Information
-            about missing entities.
         modification_time_usecs (long|int): Specifies the last time this Job
             was updated.
         modified_by_user (string): Specifies the last Cohesity user who
@@ -343,10 +317,10 @@ class ProtectionJob(object):
         "name":'name',
         "policy_id":'policyId',
         "view_box_id":'viewBoxId',
+        "leverage_san_transport":'LeverageSanTransport',
         "abort_in_blackout_period":'abortInBlackoutPeriod',
         "alerting_config":'alertingConfig',
         "alerting_policy":'alertingPolicy',
-        "allow_parallel_runs":'allowParallelRuns',
         "cloud_parameters":'cloudParameters',
         "continue_on_quiesce_failure":'continueOnQuiesceFailure',
         "create_remote_view":'createRemoteView',
@@ -357,7 +331,6 @@ class ProtectionJob(object):
         "end_time_usecs":'endTimeUsecs',
         "environment":'environment',
         "environment_parameters":'environmentParameters',
-        "exclude_label_ids":'excludeLabelIds',
         "exclude_source_ids":'excludeSourceIds',
         "exclude_vm_tag_ids":'excludeVmTagIds',
         "full_protection_sla_time_mins":'fullProtectionSlaTimeMins',
@@ -371,13 +344,10 @@ class ProtectionJob(object):
         "is_direct_archive_enabled":'isDirectArchiveEnabled',
         "is_native_format":'isNativeFormat',
         "is_paused":'isPaused',
-        "label_ids":'labelIds',
         "last_run":'lastRun',
         "leverage_nutanix_snapshots":'leverageNutanixSnapshots',
-        "leverage_san_transport":'leverageSanTransport',
         "leverage_storage_snapshots":'leverageStorageSnapshots',
         "leverage_storage_snapshots_for_hyperflex":'leverageStorageSnapshotsForHyperflex',
-        "missing_entities":'missingEntities',
         "modification_time_usecs":'modificationTimeUsecs',
         "modified_by_user":'modifiedByUser',
         "parent_source_id":'parentSourceId',
@@ -407,10 +377,10 @@ class ProtectionJob(object):
                  name=None,
                  policy_id=None,
                  view_box_id=None,
+                 leverage_san_transport=None,
                  abort_in_blackout_period=None,
                  alerting_config=None,
                  alerting_policy=None,
-                 allow_parallel_runs=None,
                  cloud_parameters=None,
                  continue_on_quiesce_failure=None,
                  create_remote_view=None,
@@ -421,7 +391,6 @@ class ProtectionJob(object):
                  end_time_usecs=None,
                  environment=None,
                  environment_parameters=None,
-                 exclude_label_ids=None,
                  exclude_source_ids=None,
                  exclude_vm_tag_ids=None,
                  full_protection_sla_time_mins=None,
@@ -435,13 +404,10 @@ class ProtectionJob(object):
                  is_direct_archive_enabled=None,
                  is_native_format=None,
                  is_paused=None,
-                 label_ids=None,
                  last_run=None,
                  leverage_nutanix_snapshots=None,
-                 leverage_san_transport=None,
                  leverage_storage_snapshots=None,
                  leverage_storage_snapshots_for_hyperflex=None,
-                 missing_entities=None,
                  modification_time_usecs=None,
                  modified_by_user=None,
                  parent_source_id=None,
@@ -468,10 +434,10 @@ class ProtectionJob(object):
         """Constructor for the ProtectionJob class"""
 
         # Initialize members of the class
+        self.leverage_san_transport = leverage_san_transport
         self.abort_in_blackout_period = abort_in_blackout_period
         self.alerting_config = alerting_config
         self.alerting_policy = alerting_policy
-        self.allow_parallel_runs = allow_parallel_runs
         self.cloud_parameters = cloud_parameters
         self.continue_on_quiesce_failure = continue_on_quiesce_failure
         self.create_remote_view = create_remote_view
@@ -482,7 +448,6 @@ class ProtectionJob(object):
         self.end_time_usecs = end_time_usecs
         self.environment = environment
         self.environment_parameters = environment_parameters
-        self.exclude_label_ids = exclude_label_ids
         self.exclude_source_ids = exclude_source_ids
         self.exclude_vm_tag_ids = exclude_vm_tag_ids
         self.full_protection_sla_time_mins = full_protection_sla_time_mins
@@ -496,13 +461,10 @@ class ProtectionJob(object):
         self.is_direct_archive_enabled = is_direct_archive_enabled
         self.is_native_format = is_native_format
         self.is_paused = is_paused
-        self.label_ids = label_ids
         self.last_run = last_run
         self.leverage_nutanix_snapshots = leverage_nutanix_snapshots
-        self.leverage_san_transport = leverage_san_transport
         self.leverage_storage_snapshots = leverage_storage_snapshots
         self.leverage_storage_snapshots_for_hyperflex = leverage_storage_snapshots_for_hyperflex
-        self.missing_entities = missing_entities
         self.modification_time_usecs = modification_time_usecs
         self.modified_by_user = modified_by_user
         self.name = name
@@ -552,7 +514,7 @@ class ProtectionJob(object):
         name = dictionary.get('name')
         policy_id = dictionary.get('policyId')
         view_box_id = dictionary.get('viewBoxId')
-        allow_parallel_runs = dictionary.get('allowParallelRuns')
+        leverage_san_transport = dictionary.get('LeverageSanTransport')
         abort_in_blackout_period = dictionary.get('abortInBlackoutPeriod')
         alerting_config = cohesity_management_sdk.models.alerting_config.AlertingConfig.from_dictionary(dictionary.get('alertingConfig')) if dictionary.get('alertingConfig') else None
         alerting_policy = dictionary.get('alertingPolicy')
@@ -566,7 +528,6 @@ class ProtectionJob(object):
         end_time_usecs = dictionary.get('endTimeUsecs')
         environment = dictionary.get('environment')
         environment_parameters = cohesity_management_sdk.models.environment_type_job_parameters.EnvironmentTypeJobParameters.from_dictionary(dictionary.get('environmentParameters')) if dictionary.get('environmentParameters') else None
-        exclude_label_ids = dictionary.get('excludeLabelIds')
         exclude_source_ids = dictionary.get('excludeSourceIds')
         exclude_vm_tag_ids = dictionary.get('excludeVmTagIds')
         full_protection_sla_time_mins = dictionary.get('fullProtectionSlaTimeMins')
@@ -580,17 +541,10 @@ class ProtectionJob(object):
         is_direct_archive_enabled = dictionary.get('isDirectArchiveEnabled')
         is_native_format = dictionary.get('isNativeFormat')
         is_paused = dictionary.get('isPaused')
-        label_ids = dictionary.get('labelIds')
         last_run = cohesity_management_sdk.models.protection_run_instance.ProtectionRunInstance.from_dictionary(dictionary.get('lastRun')) if dictionary.get('lastRun') else None
         leverage_nutanix_snapshots = dictionary.get('leverageNutanixSnapshots')
-        leverage_san_transport = dictionary.get('leverageSanTransport')
         leverage_storage_snapshots = dictionary.get('leverageStorageSnapshots')
         leverage_storage_snapshots_for_hyperflex = dictionary.get('leverageStorageSnapshotsForHyperflex')
-        missing_entities = None
-        if dictionary.get('missingEntities'):
-            missing_entities = list()
-            for structure in dictionary.get('missingEntities'):
-                missing_entities.append(cohesity_management_sdk.models.protection_source.ProtectionSource.from_dictionary(structure))
         modification_time_usecs = dictionary.get('modificationTimeUsecs')
         modified_by_user = dictionary.get('modifiedByUser')
         parent_source_id = dictionary.get('parentSourceId')
@@ -627,10 +581,10 @@ class ProtectionJob(object):
         return cls(name,
                    policy_id,
                    view_box_id,
+                   leverage_san_transport,
                    abort_in_blackout_period,
                    alerting_config,
                    alerting_policy,
-                   allow_parallel_runs,
                    cloud_parameters,
                    continue_on_quiesce_failure,
                    create_remote_view,
@@ -641,7 +595,6 @@ class ProtectionJob(object):
                    end_time_usecs,
                    environment,
                    environment_parameters,
-                   exclude_label_ids,
                    exclude_source_ids,
                    exclude_vm_tag_ids,
                    full_protection_sla_time_mins,
@@ -655,13 +608,10 @@ class ProtectionJob(object):
                    is_direct_archive_enabled,
                    is_native_format,
                    is_paused,
-                   label_ids,
                    last_run,
                    leverage_nutanix_snapshots,
-                   leverage_san_transport,
                    leverage_storage_snapshots,
                    leverage_storage_snapshots_for_hyperflex,
-                   missing_entities,
                    modification_time_usecs,
                    modified_by_user,
                    parent_source_id,
