@@ -1,8 +1,7 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2021 Cohesity Inc.
 
 import cohesity_management_sdk.models.blackout_period
-import cohesity_management_sdk.models.data_lock_config
 import cohesity_management_sdk.models.snapshot_cloud_copy_policy
 import cohesity_management_sdk.models.extended_retention_policy
 import cohesity_management_sdk.models.scheduling_policy
@@ -30,21 +29,6 @@ class ProtectionPolicy(object):
             to Cloud. CloudDeploy target where backup snapshots may be
             converted and stored. It also defines the retention of copied
             Snapshots on the Cloud.
-        datalock_config (DataLockConfig): Specifies WORM retention type for
-            the log snapshots. When a WORM retention type is specified, the
-            snapshots of the Protection Groups using this policy will be kept
-            for the last N days as specified in the duration of the datalock.
-            During that time, the snapshots cannot be deleted.
-        datalock_config_log (DataLockConfig): Specifies WORM retention type
-            for the log snapshots. When a WORM retention type is specified,the
-            snapshots of the Protection Groups using this policy will be kept
-            for the last N days as specified in the duration of the datalock.
-            During that time, the snapshots cannot be deleted.
-        datalock_config_system (DataLockConfig): Specifies WORM retention type
-            for the log snapshots. When a WORM retention type is specified,the
-            snapshots of the Protection Groups using this policy will be kept
-            for the last N days as specified in the duration of the datalock.
-            During that time, the snapshots cannot be deleted.
         days_to_keep (long|int): Specifies how many days to retain Snapshots
             on the Cohesity Cluster.
         days_to_keep_log (long|int): Specifies the number of days to retain
@@ -67,8 +51,6 @@ class ProtectionPolicy(object):
             CBT-based backup schedule of a Protection Job and how long
             Snapshots captured by this schedule are retained on the Cohesity
             Cluster.
-        is_cascaded_replication_policy (bool): Specifies if the policy is
-            associated with cascaded replication.
         is_replicated (bool): Specifies the policy is replicated policy.
         is_usable (bool): Specifies if the policy can be used to create a
             job.
@@ -120,14 +102,11 @@ class ProtectionPolicy(object):
             WORM retention type for the snapshots. When a WORM retention type
             is specified, the snapshots of the Protection Jobs using this
             policy will be kept until the maximum of the snapshot retention
-            time. During that time, the snapshots cannot be deleted. This
-            field is deprecated. Use DataLockConfig for incremental runs,
-            DataLockConfigLog for log runs, DataLockConfigSystem for BMR runs,
-            and DataLockConfig in extended retention and for copy targets
-            config. deprecated: true. 'kNone' implies there is no WORM
-            retention set. 'kCompliance' implies WORM retention is set for
-            compliance reason. 'kAdministrative' implies WORM retention is set
-            for administrative purposes.
+            time. During that time, the snapshots cannot be deleted. 'kNone'
+            implies there is no WORM retention set. 'kCompliance' implies WORM
+            retention is set for compliance reason. 'kAdministrative' implies
+            WORM retention is set for administrative purposes.
+
     """
 
     # Create a mapping from Model property names to API property names
@@ -135,9 +114,6 @@ class ProtectionPolicy(object):
         "blackout_periods":'blackoutPeriods',
         "cdp_scheduling_policy":'cdpSchedulingPolicy',
         "cloud_deploy_policies":'cloudDeployPolicies',
-        "datalock_config":'datalockConfig',
-        "datalock_config_log":'datalockConfigLog',
-        "datalock_config_system":'datalockConfigSystem',
         "days_to_keep":'daysToKeep',
         "days_to_keep_log":'daysToKeepLog',
         "days_to_keep_system":'daysToKeepSystem',
@@ -146,7 +122,6 @@ class ProtectionPolicy(object):
         "full_scheduling_policy":'fullSchedulingPolicy',
         "id":'id',
         "incremental_scheduling_policy":'incrementalSchedulingPolicy',
-        "is_cascaded_replication_policy":'isCascadedReplicationPolicy',
         "is_replicated":'isReplicated',
         "is_usable":'isUsable',
         "last_modified_time_msecs":'lastModifiedTimeMsecs',
@@ -170,9 +145,6 @@ class ProtectionPolicy(object):
                  blackout_periods=None,
                  cdp_scheduling_policy=None,
                  cloud_deploy_policies=None,
-                 datalock_config=None,
-                 datalock_config_log=None,
-                 datalock_config_system=None,
                  days_to_keep=None,
                  days_to_keep_log=None,
                  days_to_keep_system=None,
@@ -181,7 +153,6 @@ class ProtectionPolicy(object):
                  full_scheduling_policy=None,
                  id=None,
                  incremental_scheduling_policy=None,
-                 is_cascaded_replication_policy=None,
                  is_replicated=None,
                  is_usable=None,
                  last_modified_time_msecs=None,
@@ -205,9 +176,6 @@ class ProtectionPolicy(object):
         self.blackout_periods = blackout_periods
         self.cdp_scheduling_policy = cdp_scheduling_policy
         self.cloud_deploy_policies = cloud_deploy_policies
-        self.datalock_config = datalock_config
-        self.datalock_config_log = datalock_config_log
-        self.datalock_config_system = datalock_config_system
         self.days_to_keep = days_to_keep
         self.days_to_keep_log = days_to_keep_log
         self.days_to_keep_system = days_to_keep_system
@@ -216,7 +184,6 @@ class ProtectionPolicy(object):
         self.full_scheduling_policy = full_scheduling_policy
         self.id = id
         self.incremental_scheduling_policy = incremental_scheduling_policy
-        self.is_cascaded_replication_policy = is_cascaded_replication_policy
         self.is_replicated = is_replicated
         self.is_usable = is_usable
         self.last_modified_time_msecs = last_modified_time_msecs
@@ -265,9 +232,6 @@ class ProtectionPolicy(object):
             cloud_deploy_policies = list()
             for structure in dictionary.get('cloudDeployPolicies'):
                 cloud_deploy_policies.append(cohesity_management_sdk.models.snapshot_cloud_copy_policy.SnapshotCloudCopyPolicy.from_dictionary(structure))
-        datalock_config = cohesity_management_sdk.models.data_lock_config.DataLockConfig.from_dictionary(dictionary.get('datalockConfig')) if dictionary.get('datalockConfig') else None
-        datalock_config_log = cohesity_management_sdk.models.data_lock_config.DataLockConfig.from_dictionary(dictionary.get('datalockConfigLog')) if dictionary.get('datalockConfigLog') else None
-        datalock_config_system = cohesity_management_sdk.models.data_lock_config.DataLockConfig.from_dictionary(dictionary.get('datalockConfigSystem')) if dictionary.get('datalockConfigSystem') else None
         days_to_keep = dictionary.get('daysToKeep')
         days_to_keep_log = dictionary.get('daysToKeepLog')
         days_to_keep_system = dictionary.get('daysToKeepSystem')
@@ -280,7 +244,6 @@ class ProtectionPolicy(object):
         full_scheduling_policy = cohesity_management_sdk.models.scheduling_policy.SchedulingPolicy.from_dictionary(dictionary.get('fullSchedulingPolicy')) if dictionary.get('fullSchedulingPolicy') else None
         id = dictionary.get('id')
         incremental_scheduling_policy = cohesity_management_sdk.models.scheduling_policy.SchedulingPolicy.from_dictionary(dictionary.get('incrementalSchedulingPolicy')) if dictionary.get('incrementalSchedulingPolicy') else None
-        is_cascaded_replication_policy = dictionary.get('isCascadedReplicationPolicy')
         is_replicated = dictionary.get('isReplicated')
         is_usable = dictionary.get('isUsable')
         last_modified_time_msecs = dictionary.get('lastModifiedTimeMsecs')
@@ -311,9 +274,6 @@ class ProtectionPolicy(object):
         return cls(blackout_periods,
                    cdp_scheduling_policy,
                    cloud_deploy_policies,
-                   datalock_config,
-                   datalock_config_log,
-                   datalock_config_system,
                    days_to_keep,
                    days_to_keep_log,
                    days_to_keep_system,
@@ -322,7 +282,6 @@ class ProtectionPolicy(object):
                    full_scheduling_policy,
                    id,
                    incremental_scheduling_policy,
-                   is_cascaded_replication_policy,
                    is_replicated,
                    is_usable,
                    last_modified_time_msecs,
