@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2021 Cohesity Inc.
 
 import cohesity_management_sdk.models.aws_credentials
 import cohesity_management_sdk.models.a_w_s_fleet_params
@@ -9,7 +9,6 @@ import cohesity_management_sdk.models.fleet_network_params
 import cohesity_management_sdk.models.gcp_credentials
 import cohesity_management_sdk.models.registered_protection_source_isilon_params
 import cohesity_management_sdk.models.kubernetes_credentials
-import cohesity_management_sdk.models.kubernetes_params
 import cohesity_management_sdk.models.nas_mount_credential_params
 import cohesity_management_sdk.models.office_365_credentials
 import cohesity_management_sdk.models.physical_params
@@ -47,9 +46,6 @@ class RegisterProtectionSourceParameters(object):
         cluster_network_info (FleetNetworkParams): Specifies information
             related to cluster. This is only valid for CE clusters. This is
             only populated for kIAMUser entity.
-        connection_id (long|int): Specifies the Bifrost realm to be associated
-            with the source root. Whenever needed, the workflows related to
-            this source would then only use Bifrosts from the specified realm.
         denied_ip_addresses (list of string): Specifies the list of IP
             Addresses on the registered source to be denied for doing any
             type of IO operations.
@@ -105,8 +101,7 @@ class RegisterProtectionSourceParameters(object):
             environment. 'kCouchbase' indicates Couchbase Protection Source
             environment. 'kHdfs' indicates Hdfs Protection Source environment.
             'kHive' indicates Hive Protection Source environment. 'kHBase'
-            indicates HBase Protection Source environment. 'kUDA' indicates
-            Universal Data Adapter Protection Source environment.
+            indicates HBase Protection Source environment.
         exchange_dag_protection_preference (ExchangeDAGProtectionPreference):
             Specifies information about the preference order while choosing
             between which database copy of the exchange database which is part
@@ -137,8 +132,6 @@ class RegisterProtectionSourceParameters(object):
             registered protection source params for Isilon Source
         kubernetes_credentials (KubernetesCredentials): Specifies the
             credentials to authenticate with a Kubernetes Cluster.
-        kubernetes_params (KubernetesParams):  Extra parameters needed for
-            registering a K8s resource.
         kubernetes_type (KubernetesTypeEnum): Specifies the entity type if the
             environment is kKubernetes. overrideDescription: true
         kvm_type (KvmTypeEnum): Specifies the entity type if the environment
@@ -171,11 +164,6 @@ class RegisterProtectionSourceParameters(object):
             belong to a office365 domain.
         pure_type (PureTypeEnum): Specifies the entity type such as
             'kStorageArray' if the environment is kPure.
-        re_register (bool): ReRegister is applicable to Physical Environment.
-            By default, the agent running on a physical host will fail the
-            registration, if it is already registered with the cluster. By
-            setting this option to true, agent can be re-registered with the
-            current cluster.
         source_side_dedup_enabled (bool): This controls whether to use source
             side dedup on the source or not. This is only applicable to
             sources which support source side dedup (e.g., Linux physical
@@ -221,7 +209,6 @@ class RegisterProtectionSourceParameters(object):
         "azure_credentials":'azureCredentials',
         "blacklisted_ip_addresses":'blacklistedIpAddresses',
         "cluster_network_info":'clusterNetworkInfo',
-        "connection_id":'connectionId',
         "denied_ip_addresses":'deniedIpAddresses',
         "endpoint":'endpoint',
         "encryption_key":'encryptionKey',
@@ -248,7 +235,6 @@ class RegisterProtectionSourceParameters(object):
         "physical_type":'physicalType',
         "proxy_host_source_id_list":'proxyHostSourceIdList',
         "pure_type":'pureType',
-        "re_register":'reRegister',
         "source_side_dedup_enabled":'sourceSideDedupEnabled',
         "ssl_verification":'sslVerification',
         "subnets":'subnets',
@@ -270,7 +256,6 @@ class RegisterProtectionSourceParameters(object):
                  azure_credentials=None,
                  blacklisted_ip_addresses=None,
                  cluster_network_info=None,
-                 connection_id=None,
                  denied_ip_addresses=None,
                  encryption_key=None,
                  endpoint=None,
@@ -284,7 +269,6 @@ class RegisterProtectionSourceParameters(object):
                  is_proxy_host=None,
                  isilon_params=None,
                  kubernetes_credentials=None,
-                 kubernetes_params=None,
                  kubernetes_type=None,
                  kvm_type=None,
                  nas_mount_credentials=None,
@@ -298,7 +282,6 @@ class RegisterProtectionSourceParameters(object):
                  physical_type=None,
                  proxy_host_source_id_list=None,
                  pure_type=None,
-                 re_register=None,
                  source_side_dedup_enabled=None,
                  ssl_verification=None,
                  subnets=None,
@@ -320,7 +303,6 @@ class RegisterProtectionSourceParameters(object):
         self.azure_credentials = azure_credentials
         self.blacklisted_ip_addresses = blacklisted_ip_addresses
         self.cluster_network_info = cluster_network_info
-        self.connection_id = connection_id
         self.denied_ip_addresses = denied_ip_addresses
         self.encryption_key = encryption_key
         self.endpoint = endpoint
@@ -334,7 +316,6 @@ class RegisterProtectionSourceParameters(object):
         self.is_proxy_host = is_proxy_host
         self.isilon_params = isilon_params
         self.kubernetes_credentials = kubernetes_credentials
-        self.kubernetes_params = kubernetes_params
         self.kubernetes_type = kubernetes_type
         self.kvm_type = kvm_type
         self.nas_mount_credentials = nas_mount_credentials
@@ -348,7 +329,6 @@ class RegisterProtectionSourceParameters(object):
         self.physical_type = physical_type
         self.proxy_host_source_id_list = proxy_host_source_id_list
         self.pure_type = pure_type
-        self.re_register = re_register
         self.source_side_dedup_enabled = source_side_dedup_enabled
         self.ssl_verification = ssl_verification
         self.subnets = subnets
@@ -387,7 +367,6 @@ class RegisterProtectionSourceParameters(object):
         azure_credentials = cohesity_management_sdk.models.azure_credentials.AzureCredentials.from_dictionary(dictionary.get('azureCredentials')) if dictionary.get('azureCredentials') else None
         blacklisted_ip_addresses = dictionary.get('blacklistedIpAddresses')
         cluster_network_info = cohesity_management_sdk.models.fleet_network_params.FleetNetworkParams.from_dictionary(dictionary.get('clusterNetworkInfo')) if dictionary.get('clusterNetworkInfo') else None
-        connection_id = dictionary.get('connectionId')
         denied_ip_addresses = dictionary.get('deniedIpAddresses')
         encryption_key = dictionary.get('encryptionKey')
         endpoint = dictionary.get('endpoint')
@@ -401,7 +380,6 @@ class RegisterProtectionSourceParameters(object):
         is_proxy_host = dictionary.get('isProxyHost')
         isilon_params = cohesity_management_sdk.models.registered_protection_source_isilon_params.RegisteredProtectionSourceIsilonParams.from_dictionary(dictionary.get('isilonParams')) if dictionary.get('isilonParams') else None
         kubernetes_credentials = cohesity_management_sdk.models.kubernetes_credentials.KubernetesCredentials.from_dictionary(dictionary.get('kubernetesCredentials')) if dictionary.get('kubernetesCredentials') else None
-        kubernetes_params = cohesity_management_sdk.models.kubernetes_params.KubernetesParams.from_dictionary(dictionary.get('kubernetesParams')) if dictionary.get('kubernetesParams') else None
         kubernetes_type = dictionary.get('kubernetesType')
         kvm_type = dictionary.get('kvmType')
         nas_mount_credentials = cohesity_management_sdk.models.nas_mount_credential_params.NasMountCredentialParams.from_dictionary(dictionary.get('nasMountCredentials')) if dictionary.get('nasMountCredentials') else None
@@ -419,7 +397,6 @@ class RegisterProtectionSourceParameters(object):
         physical_type = dictionary.get('physicalType')
         proxy_host_source_id_list = dictionary.get('proxyHostSourceIdList')
         pure_type = dictionary.get('pureType')
-        re_register = dictionary.get('reRegister')
         source_side_dedup_enabled = dictionary.get('sourceSideDedupEnabled')
         ssl_verification = cohesity_management_sdk.models.ssl_verification.SslVerification.from_dictionary(dictionary.get('sslVerification')) if dictionary.get('sslVerification') else None
         subnets = None
@@ -448,7 +425,6 @@ class RegisterProtectionSourceParameters(object):
                    azure_credentials,
                    blacklisted_ip_addresses,
                    cluster_network_info,
-                   connection_id,
                    denied_ip_addresses,
                    encryption_key,
                    endpoint,
@@ -462,7 +438,6 @@ class RegisterProtectionSourceParameters(object):
                    is_proxy_host,
                    isilon_params,
                    kubernetes_credentials,
-                   kubernetes_params,
                    kubernetes_type,
                    kvm_type,
                    nas_mount_credentials,
@@ -476,7 +451,6 @@ class RegisterProtectionSourceParameters(object):
                    physical_type,
                    proxy_host_source_id_list,
                    pure_type,
-                   re_register,
                    source_side_dedup_enabled,
                    ssl_verification,
                    subnets,
