@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2021 Cohesity Inc.
 
 import cohesity_management_sdk.models.restore_files_params_directory_name_security_style_map_entry
 import cohesity_management_sdk.models.entity_proto
@@ -71,9 +71,6 @@ class RestoreFilesParams(object):
             host type for VMware entities.
         uptier_params (FileUptieringParams): Set if this is NAS Migration
             uptier operation.
-        use_existing_agent (bool): Whether this will use an existing agent on
-            the target VM to do the restore. This field is deprecated.
-            restore_method should be used for populating use of existing agent.
         vpc_connector_entity (EntityProto): Specifies the attributes and the
             latest statistics about an entity.
         whitelisted_ip_addrs (list of string): A list of target IP addresses
@@ -104,7 +101,6 @@ class RestoreFilesParams(object):
         "target_host_entity":'targetHostEntity',
         "target_host_type":'targetHostType',
         "uptier_params":'uptierParams',
-        "use_existing_agent":'useExistingAgent',
         "vpc_connector_entity":'vpcConnectorEntity',
         "whitelisted_ip_addrs":'whitelistedIpAddrs'
     }
@@ -131,7 +127,6 @@ class RestoreFilesParams(object):
                  target_host_entity=None,
                  target_host_type=None,
                  uptier_params=None,
-                 use_existing_agent=None,
                  vpc_connector_entity=None,
                  whitelisted_ip_addrs=None):
         """Constructor for the RestoreFilesParams class"""
@@ -158,7 +153,6 @@ class RestoreFilesParams(object):
         self.target_host_entity = target_host_entity
         self.target_host_type = target_host_type
         self.uptier_params = uptier_params
-        self.use_existing_agent = use_existing_agent
         self.vpc_connector_entity = vpc_connector_entity
         self.whitelisted_ip_addrs = whitelisted_ip_addrs
 
@@ -210,7 +204,6 @@ class RestoreFilesParams(object):
         target_host_entity = cohesity_management_sdk.models.entity_proto.EntityProto.from_dictionary(dictionary.get('targetHostEntity')) if dictionary.get('targetHostEntity') else None
         target_host_type = dictionary.get('targetHostType')
         uptier_params = cohesity_management_sdk.models.file_uptiering_params.FileUptieringParams.from_dictionary(dictionary.get('uptierParams')) if dictionary.get('uptierParams') else None
-        use_existing_agent = dictionary.get('useExistingAgent')
         vpc_connector_entity = cohesity_management_sdk.models.entity_proto.EntityProto.from_dictionary(dictionary.get('vpcConnectorEntity')) if dictionary.get('vpcConnectorEntity') else None
         whitelisted_ip_addrs = dictionary.get('whitelistedIpAddrs')
 
@@ -236,7 +229,6 @@ class RestoreFilesParams(object):
                    target_host_entity,
                    target_host_type,
                    uptier_params,
-                   use_existing_agent,
                    vpc_connector_entity,
                    whitelisted_ip_addrs)
 
