@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2021 Cohesity Inc.
 
 import cohesity_management_sdk.models.connector_params
 import cohesity_management_sdk.models.entity_proto
@@ -16,28 +16,23 @@ class StorageSnapshotProviderParams(object):
             particular environment.
         entity (EntityProto): Specifies the attributes and the latest
             statistics about an entity.
-        root_entity (EntityProto): The root entity that the entity was
-            running under.
 
     """
 
     # Create a mapping from Model property names to API property names
     _names = {
         "connector_params":'connectorParams',
-        "entity":'entity',
-        "root_entity":'rootEntity'
+        "entity":'entity'
     }
 
     def __init__(self,
                  connector_params=None,
-                 entity=None,
-                 root_entity=None):
+                 entity=None):
         """Constructor for the StorageSnapshotProviderParams class"""
 
         # Initialize members of the class
         self.connector_params = connector_params
         self.entity = entity
-        self.root_entity = root_entity
 
 
     @classmethod
@@ -60,11 +55,9 @@ class StorageSnapshotProviderParams(object):
         # Extract variables from the dictionary
         connector_params = cohesity_management_sdk.models.connector_params.ConnectorParams.from_dictionary(dictionary.get('connectorParams')) if dictionary.get('connectorParams') else None
         entity = cohesity_management_sdk.models.entity_proto.EntityProto.from_dictionary(dictionary.get('entity')) if dictionary.get('entity') else None
-        root_entity = cohesity_management_sdk.models.entity_proto.EntityProto.from_dictionary(dictionary.get('rootEntity')) if dictionary.get('rootEntity') else None
 
         # Return an object of this model
         return cls(connector_params,
-                   entity,
-                   root_entity)
+                   entity)
 
 
