@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2021 Cohesity Inc.
 
 class SubscriptionTypeAzureProtectionSourceEnum(object):
 
@@ -10,13 +10,12 @@ class SubscriptionTypeAzureProtectionSourceEnum(object):
     'kAzureCommercial' indicates a standard Azure subscription.
     'kAzureGovCloud' indicates a govt Azure subscription.
     'kAzureStackCommercial' indicates a stack commercial Azure subscription.
-    'kAzureStackADFS' indicates a ADFS Azure subbscription.
+        
 
     Attributes:
         KAZURECOMMERCIAL: TODO: type description here.
         KAZUREGOVCLOUD: TODO: type description here.
         KAZURESTACKCOMMERCIAL: TODO: type description here.
-        KAZURESTACKADFS: TODO: type description here.
 
     """
 
@@ -25,5 +24,3 @@ class SubscriptionTypeAzureProtectionSourceEnum(object):
     K_AZURE_GO_VCLOUD = 'kAzureGovCloud'
 
     KAZURESTACKCOMMERCIAL = 'kAzureStackCommercial'
-
-    KAZURESTACKADFS = 'kAzureStackADFS'
