@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2021 Cohesity Inc.
 
 class TypeRunJobSnapshotTargetEnum(object):
 
@@ -19,7 +19,6 @@ class TypeRunJobSnapshotTargetEnum(object):
         KREMOTE: TODO: type description here.
         KARCHIVAL: TODO: type description here.
         KCLOUDDEPLOY: TODO: type description here.
-        KCLOUDREPLICATION: TODO: type description here.
 
     """
 
@@ -31,5 +30,3 @@ class TypeRunJobSnapshotTargetEnum(object):
 
     KCLOUDDEPLOY = 'kCloudDeploy'
 
-    KCLOUDREPLICATION =  'kCloudReplication'
-
