@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2021 Cohesity Inc.
 
 import cohesity_management_sdk.models.gflag
 
@@ -43,7 +43,8 @@ class UpdateGflagParameters(object):
             responsible for creation of Clusters and configuration of Nodes
             and networking. 'kNexusProxy' is a service that links the Nexus
             service to other services on the Cluster. 'kStorageProxy' is a
-            service for accessing data on external entities. 'kRtClient' is a
+            service for accessing data on external entities. 'kTricorder' is a
+            diagnostic health testing service for Clusters. 'kRtClient' is a
             reverse tunneling client service. 'kVaultProxy' is a service for
             managing external targets that Clusters can be backed up to.
             'kSmbProxy' is an SMB protocol service. 'kBridgeProxy' is the
@@ -59,10 +60,9 @@ class UpdateGflagParameters(object):
             can be specified in order to do a full reboot.
             'kAtom' is a service for receiving data for the Continuous Data
             Protection.
-            'kEtlServer' is a service responsible for ETling data for
-            globalsearch.
-            'kIcebox' is service that links Icebox service to other services on
-            cluster.
+            'kPatch' is a service for downloading and applying patches.
+            'kCompass' is a service for serving dns request for external and
+            internal traffic.
 
     """
 
