@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Cohesity Inc.
+# Copyright 2021 Cohesity Inc.
 
 import cohesity_management_sdk.models.aws_credentials
 import cohesity_management_sdk.models.a_w_s_fleet_params
@@ -8,7 +8,6 @@ import cohesity_management_sdk.models.fleet_network_params
 import cohesity_management_sdk.models.gcp_credentials
 import cohesity_management_sdk.models.registered_protection_source_isilon_params
 import cohesity_management_sdk.models.kubernetes_credentials
-import cohesity_management_sdk.models.kubernetes_params
 import cohesity_management_sdk.models.nas_mount_credential_params
 import cohesity_management_sdk.models.office_365_credentials
 import cohesity_management_sdk.models.ssl_verification
@@ -44,10 +43,6 @@ class UpdateProtectionSourceParameters(object):
         cluster_network_info (FleetNetworkParams): Specifies information
             related to cluster. This is only valid for CE clusters. This is
             only populated for kIAMUser entity.
-        connection_id (long|int): Specifies the Bifrost realm to be
-            associated with the source root. Whenever needed, the workflows
-            related to this source would then only use Bifrosts from the
-            specified realm.
         denied_ip_addresses (list of string): Specifies the list of IP
             Addresses on the registered source to be denied for doing any
             type of IO operations.
@@ -80,8 +75,6 @@ class UpdateProtectionSourceParameters(object):
             registered protection source params for Isilon Source
         kubernetes_credentials (KubernetesCredentials): Specifies the
             credentials to authenticate with a Kubernetes Cluster.
-        kubernetes_params (KubernetesParams): Extra parameters needed for
-            updating a K8s resource.
         minimum_free_space_gb (long|int): Specifies the minimum space in GB
             after which backup jobs will be canceled due to low space.
         nas_mount_credentials (NasMountCredentialParams): Specifies the server
@@ -96,11 +89,6 @@ class UpdateProtectionSourceParameters(object):
             the protection source id of the windows physical host which will
             be used during the protection and recovery of the sites that
             belong to a office365 domain.
-        re_register (bool): ReRegister is applicable to Physical Environment.
-            By default, the agent running on a physical host will fail the
-            registration, if it is already registered with the cluster. By
-            setting this option to true, agent can be re-registered with the
-            current cluster.
         source_side_dedup_enabled (bool): This controls whether to use source
             side dedup on the source or not. This is only applicable to
             sources which support source side dedup (e.g., Linux physical
@@ -138,7 +126,6 @@ class UpdateProtectionSourceParameters(object):
         "azure_credentials":'azureCredentials',
         "blacklisted_ip_addresses":'blacklistedIpAddresses',
         "cluster_network_info":'clusterNetworkInfo',
-        "connection_id":'connectionId',
         "denied_ip_addresses":'deniedIpAddresses',
         "endpoint":'endpoint',
         "exchange_dag_protection_preference":'exchangeDagProtectionPreference',
@@ -148,14 +135,12 @@ class UpdateProtectionSourceParameters(object):
         "is_proxy_host":'isProxyHost',
         "isilon_params":'isilonParams',
         "kubernetes_credentials":'kubernetesCredentials',
-        "kubernetes_params":'kubernetesParams',
         "minimum_free_space_gb":'minimumFreeSpaceGB',
         "nas_mount_credentials":'nasMountCredentials',
         "office_365_credentials":'office365Credentials',
         "office_365_region":'office365Region',
         "password":'password',
         "proxy_host_source_id_list":'proxyHostSourceIdList',
-        "re_register":'reRegister',
         "source_side_dedup_enabled":'sourceSideDedupEnabled',
         "ssl_verification":'sslVerification',
         "subnets":'subnets',
@@ -174,7 +159,6 @@ class UpdateProtectionSourceParameters(object):
                  azure_credentials=None,
                  blacklisted_ip_addresses=None,
                  cluster_network_info=None,
-                 connection_id=None,
                  denied_ip_addresses=None,
                  endpoint=None,
                  exchange_dag_protection_preference=None,
@@ -184,14 +168,12 @@ class UpdateProtectionSourceParameters(object):
                  isilon_params=None,
                  host_type=None,
                  kubernetes_credentials=None,
-                 kubernetes_params=None,
                  minimum_free_space_gb=None,
                  nas_mount_credentials=None,
                  office_365_credentials=None,
                  office_365_region=None,
                  password=None,
                  proxy_host_source_id_list=None,
-                 re_register=None,
                  source_side_dedup_enabled=None,
                  ssl_verification=None,
                  subnets=None,
@@ -210,7 +192,6 @@ class UpdateProtectionSourceParameters(object):
         self.azure_credentials = azure_credentials
         self.blacklisted_ip_addresses = blacklisted_ip_addresses
         self.cluster_network_info = cluster_network_info
-        self.connection_id = connection_id
         self.denied_ip_addresses = denied_ip_addresses
         self.endpoint = endpoint
         self.exchange_dag_protection_preference = exchange_dag_protection_preference
@@ -220,14 +201,12 @@ class UpdateProtectionSourceParameters(object):
         self.isilon_params = isilon_params
         self.host_type = host_type
         self.kubernetes_credentials = kubernetes_credentials
-        self.kubernetes_params = kubernetes_params
         self.minimum_free_space_gb = minimum_free_space_gb
         self.nas_mount_credentials = nas_mount_credentials
         self.office_365_credentials = office_365_credentials
         self.office_365_region = office_365_region
         self.password = password
         self.proxy_host_source_id_list = proxy_host_source_id_list
-        self.re_register = re_register
         self.source_side_dedup_enabled = source_side_dedup_enabled
         self.ssl_verification = ssl_verification
         self.subnets = subnets
@@ -263,7 +242,6 @@ class UpdateProtectionSourceParameters(object):
         azure_credentials = cohesity_management_sdk.models.azure_credentials.AzureCredentials.from_dictionary(dictionary.get('azureCredentials')) if dictionary.get('azureCredentials') else None
         blacklisted_ip_addresses = dictionary.get('blacklistedIpAddresses')
         cluster_network_info = cohesity_management_sdk.models.fleet_network_params.FleetNetworkParams.from_dictionary(dictionary.get('clusterNetworkInfo')) if dictionary.get('clusterNetworkInfo') else None
-        connection_id = dictionary.get('connectionId')
         denied_ip_addresses = dictionary.get('deniedIpAddresses')
         exchange_dag_protection_preference = cohesity_management_sdk.models.exchange_dag_protection_preference.ExchangeDAGProtectionPreference.from_dictionary(dictionary.get('exchangeDagProtectionPreference')) if dictionary.get('exchangeDagProtectionPreference') else None
         endpoint = dictionary.get('endpoint')
@@ -273,14 +251,12 @@ class UpdateProtectionSourceParameters(object):
         is_proxy_host = dictionary.get('isProxyHost')
         isilon_params = cohesity_management_sdk.models.registered_protection_source_isilon_params.RegisteredProtectionSourceIsilonParams.from_dictionary(dictionary.get('isilonParams')) if dictionary.get('isilonParams') else None
         kubernetes_credentials = cohesity_management_sdk.models.kubernetes_credentials.KubernetesCredentials.from_dictionary(dictionary.get('kubernetesCredentials')) if dictionary.get('kubernetesCredentials') else None
-        kubernetes_params = cohesity_management_sdk.models.kubernetes_params.KubernetesParams.from_dictionary(dictionary.get('kubernetesParams')) if dictionary.get('kubernetesParams') else None
         minimum_free_space_gb = dictionary.get('minimumFreeSpaceGB')
         nas_mount_credentials = cohesity_management_sdk.models.nas_mount_credential_params.NasMountCredentialParams.from_dictionary(dictionary.get('nasMountCredentials')) if dictionary.get('nasMountCredentials') else None
         office_365_credentials = cohesity_management_sdk.models.office_365_credentials.Office365Credentials.from_dictionary(dictionary.get('office365Credentials')) if dictionary.get('office365Credentials') else None
         office_365_region = dictionary.get('office365Region')
         password = dictionary.get('password')
         proxy_host_source_id_list = dictionary.get('proxyHostSourceIdList')
-        re_register = dictionary.get('reRegister')
         source_side_dedup_enabled = dictionary.get('sourceSideDedupEnabled')
         ssl_verification = cohesity_management_sdk.models.ssl_verification.SslVerification.from_dictionary(dictionary.get('sslVerification')) if dictionary.get('sslVerification') else None
         subnets = None
@@ -306,7 +282,6 @@ class UpdateProtectionSourceParameters(object):
                    azure_credentials,
                    blacklisted_ip_addresses,
                    cluster_network_info,
-                   connection_id,
                    denied_ip_addresses,
                    endpoint,
                    exchange_dag_protection_preference,
@@ -316,14 +291,12 @@ class UpdateProtectionSourceParameters(object):
                    is_proxy_host,
                    isilon_params,
                    kubernetes_credentials,
-                   kubernetes_params,
                    minimum_free_space_gb,
                    nas_mount_credentials,
                    office_365_credentials,
                    office_365_region,
                    password,
                    proxy_host_source_id_list,
-                   re_register,
                    source_side_dedup_enabled,
                    ssl_verification,
                    subnets,
